CaptureRequest

Struct CaptureRequest 

pub struct CaptureRequest {
    pub source_url: IndexUrl,
    pub html: String,
    pub diagnostic: Option<String>,
}
Local capture request.

Fields

source_url: IndexUrl

Source URL whose page shape is represented by this local capture.

html: String

Raw HTML or snapshot source supplied locally by the user.

diagnostic: Option<String>

Optional local diagnostic context.

Implementations

Source

impl CaptureRequest

pub fn new( source_url: impl AsRef<str>, html: impl Into<String>, ) -> Result<Self, CaptureError>

Creates a capture request from a source URL string and local HTML.

pub fn with_diagnostic(self, diagnostic: impl Into<String>) -> Self

Adds local diagnostic context to the capture request.