pub struct CaptureRequest {
pub source_url: IndexUrl,
pub html: String,
pub diagnostic: Option<String>,
}Expand description
Local capture request.
Fields
source_url: IndexUrlSource URL whose page shape is represented by this local capture.
html: StringRaw HTML or snapshot source supplied locally by the user.
diagnostic: Option<String>Optional local diagnostic context.
Implementations